@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from PySide import QtCore, QtGui
+from PyQt4 import QtCore, QtGui
 
 from ListSessions import Ui_ListSessions
 from ViewSessionExt import ViewSessionExt
@@ -158,19 +158,7 @@ class ListSessionsExt( QtGui.QMainWindow ):
 
 	#добавляет в список сессий пункт сессии
 	def addItemSession(self, textItem, typeS, timeS, traffS):
-		item_pic = ""
-		if typeS == "gprs0":
-			item_pic = ":/pic48/pictures/gprs.png"
-		elif typeS == "wlan0":
-			item_pic = ":/pic48/pictures/wifi.png"
-		elif typeS == "pan0":
-			item_pic = ":/pic48/pictures/pan.png"
-		elif ( typeS == "eth0" ):
-			item_pic = ":/pic48/pictures/eth.png"
-		elif ( typeS == "usb0" ):
-			item_pic = ":/pic48/pictures/usb.png"
-		else:
-			item_pic = ":/pic48/pictures/unknown.png"
+		item_pic = StatistData.pixmapIface_str( typeS )
 		item = QtGui.QListWidgetItem()
 
 		txt = QtGui.QApplication.translate("ListSessionsExt", "Session full time:", None, QtGui.QApplication.UnicodeUTF8)
@@ -192,7 +180,6 @@ class ListSessionsExt( QtGui.QMainWindow ):
 			self.ui.pBFilter.setChecked( True )
 		else:
 			self.ui.pBFilter.setChecked( False )
-			#self.initItemsSession()
 			self.initItemsSession( self.startTime_filter, self.endTime_filter, self.sessionType_filter )
 
 
