@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from PySide import QtCore, QtGui
+from PyQt4 import QtCore, QtGui
 from string import find, replace
 
 
@@ -21,7 +21,7 @@ class MyItemDelegate(QtGui.QAbstractItemDelegate):
 			out = QtCore.QTextStream(data) #QTextStream
 			while ( not out.atEnd() or (start < 2) ):
 				line = out.readLine() #QString
-				if ( find(line, "color[\"DefaultTextColor\"]") != -1 ):
+				if ( find("%s"%line, "color[\"DefaultTextColor\"]") != -1 ):
 					line = replace(line, "color[\"DefaultTextColor\"]", "")
 					line = replace(line, "=", "")
 					line = replace(line, "\"", "")
@@ -29,7 +29,7 @@ class MyItemDelegate(QtGui.QAbstractItemDelegate):
 					line = replace(line, " ", "")
 					self.color1 = line
 					start += 1 #++start
-				if ( find(line,"color[\"SecondaryTextColor\"]") != -1 ):
+				if ( find("%s"%line,"color[\"SecondaryTextColor\"]") != -1 ):
 					line = replace(line, "color[\"SecondaryTextColor\"]", "")
 					line = replace(line, "=", "") 
 					line = replace(line, "\"", "")
@@ -44,8 +44,8 @@ class MyItemDelegate(QtGui.QAbstractItemDelegate):
 	def paint(self, painter, option, index): #(self, QObject, QStyleOptionViewItem, QModelIndex)
 		fm = option.fontMetrics # fm - QFontMetrics
 
-		name = index.data(QtCore.Qt.StatusTipRole)#.toString() #QString
-		desc = index.data(QtCore.Qt.UserRole+1)#.toString()
+		name = index.data(QtCore.Qt.StatusTipRole).toString() #QString
+		desc = index.data(QtCore.Qt.UserRole+1).toString()
 
 		painter.save()
 		r = option.rect #QRect
@@ -68,7 +68,9 @@ class MyItemDelegate(QtGui.QAbstractItemDelegate):
 				painter.drawPixmap( r.left()+6, r.top()+16, 38, 38, choff )
 			space = 58
 
-		icon = QtGui.QPixmap(index.data(QtCore.Qt.UserRole+2))#.toString())
+		icon_path = index.data(QtCore.Qt.UserRole+2)
+		icon_path = "%s"%icon_path.toString()
+		icon = QtGui.QPixmap( icon_path )#.toString())
 		painter.drawPixmap( r.left()+space, r.top()+11, 48, 48, icon )
 
 		if ( index.data(QtCore.Qt.UserRole+4) != "" ):
@@ -84,6 +86,7 @@ class MyItemDelegate(QtGui.QAbstractItemDelegate):
 		painter.setFont(f)
 
 
+		#name = fm.elidedText(name, r.width()-56-space, QtCore.Qt.ElideRight) #!!!!
 		name = fm.elidedText(name, QtCore.Qt.ElideRight, r.width()-56-space)
 		#//desc = fm.elidedText(desc, Qt::ElideRight, r.width()-64-space)
 
@@ -92,7 +95,7 @@ class MyItemDelegate(QtGui.QAbstractItemDelegate):
 			painter.drawText(r.left()+54+space, r.top()+1, r.width()-12, r.height(), QtCore.Qt.AlignVCenter|QtCore.Qt.AlignLeft, name )
 		else:
 			#painter.drawText(r.left()+54+space, r.top()+4, r.width()-12, r.height()-8, (QtCore.Qt.AlignTop|QtCore.Qt.AlignLeft), name, r)
-			painter.drawText(r.left()+54+space, r.top()+4, r.width()-12, r.height()-8, (QtCore.Qt.AlignTop|QtCore.Qt.AlignLeft), name )
+			painter.drawText(r.left()+54+space, int("%s"%r.top(),10)+4, int("%s"%r.width(),10)-12, int("%s"%r.height(),10)-8, (QtCore.Qt.AlignTop|QtCore.Qt.AlignLeft), name )
 		f.setBold( False )
 		painter.setFont( f )
 
