@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from PySide import QtCore, QtGui
+from PyQt4 import QtCore, QtGui
 
 from MyNotify import MyNotify
 import ViewCurrentSession
@@ -23,6 +23,9 @@ import myconfig
 
 import sys
 
+QtCore.Signal = QtCore.pyqtSignal
+QtCore.Slot = QtCore.pyqtSlot
+
 class MyGraphicsScene( QtGui.QGraphicsScene ):
 	mousePressed = QtCore.Signal(int,int)
 	def __init__(self, parent = None):
@@ -427,6 +430,16 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.ui_dlgMO.pbTraffTX.toggled.connect( self.changeShowTX )
 		self.ui_dlgMO.sbTimestamp.valueChanged.connect( self.changeTimestamp )
 
+		pic = QtGui.QPixmap(":/pic128/pictures/2dowarrow_128.png")
+		self.frm.lblInput.setPixmap( pic.scaled(32,32) )
+		self.frm.lblIndexRX.setPixmap( pic.scaled(16,16) )
+		self.frm.lblInput.setText("")
+			
+		pic = QtGui.QPixmap(":/pic128/pictures/2uparrow_128.png")
+		self.frm.lblOutput.setPixmap( pic.scaled(32,32) )
+		self.frm.lblIndexTX.setPixmap( pic.scaled(16,16) )
+		self.frm.lblOutput.setText("")
+
 
 	def changeShowRX(self, state):
 		self.showRX = state
@@ -591,23 +604,12 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.ui_dlgIface.lWIface.clear()
 		listSupportIface = self.db.optGetSupportIface()
 		for i in listSupportIface:
-			if i['iface'] == "gprs0":
-				item_pic = QtGui.QPixmap(":/pic48/pictures/gprs.png" )
-			elif i['iface'] == "wlan0":
-				item_pic = QtGui.QPixmap(":/pic48/pictures/wifi.png" )
-			elif i['iface'] == "pan0":
-				item_pic = QtGui.QPixmap(":/pic48/pictures/pan.png" )
-			elif i['iface'] == "eth0":
-				item_pic = QtGui.QPixmap(":/pic48/pictures/eth.png" )
-			elif i['iface'] == "usb0":
-				item_pic = QtGui.QPixmap(":/pic48/pictures/usb.png" )
-			else:
-				item_pic = QtGui.QPixmap(":/pic48/pictures/unknown.png" )
+			item_pic = StatistData.pixmapIface_pic( i['iface'] )
 			item = QtGui.QListWidgetItem( QtGui.QIcon(item_pic), i['iface'] )
 			self.ui_dlgIface.lWIface.addItem( item )
 		
 		self.ui_dlgIface.lblIface.setText( "%s"%self.iface )
-		self.ui_dlgIface.lblIfacePixmap.setPixmap( StatistData.pixmapIface(self.iface) )
+		self.ui_dlgIface.lblIfacePixmap.setPixmap( StatistData.pixmapIface_pic(self.iface) )
 		i = self.ui_dlgIface.lWIface.findItems( "%s"%self.iface, QtCore.Qt.MatchExactly)
 		if len(i) > 0:
 			self.ui_dlgIface.lWIface.setCurrentItem( i[0] )
@@ -619,7 +621,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 	def itemClickedNetworkIface(self, item):
 		self.ui_dlgIface.lblIface.setText( item.text() )
-		self.ui_dlgIface.lblIfacePixmap.setPixmap( StatistData.pixmapIface( item.text() ) )
+		self.ui_dlgIface.lblIfacePixmap.setPixmap( StatistData.pixmapIface_pic( item.text() ) )
 
 	def cancelDlgNetworkIface(self):
 		self.dlgIface.hide()
