@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from PySide import QtCore, QtGui
+from PyQt4 import QtCore, QtGui
 
 import ViewSession
 import StatistData
@@ -583,12 +583,12 @@ class ViewSessionExt( QtGui.QMainWindow ):
 
 	def slotAddComment( self ):
 		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment on the session is saved", None, QtGui.QApplication.UnicodeUTF8)
-		self.noti.notify( txt )
+		self.noti.notify( "%s"%txt )
 
 	def slotDelComment( self ):
 		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment on the session is removed", None, QtGui.QApplication.UnicodeUTF8)
-		self.noti.notify( txt )
+		self.noti.notify( "%s"%txt )
 	
 	def slotFailComment( self ):
 		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment write error", None, QtGui.QApplication.UnicodeUTF8)
-		self.noti.notify( txt )
+		self.noti.notify( "%s"%txt )
