@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from PySide import QtCore, QtGui
+from PyQt4 import QtCore, QtGui
 from WinNetStatProc import Ui_WinNetStat
 from MyNotify import MyNotify
 from DialogRefreshNetstat import Ui_DialogRefreshNetstat
@@ -217,7 +217,7 @@ class WinNetStatExt( QtGui.QMainWindow ):
 			out = QtCore.QTextStream(data) #QTextStream
 			while ( not out.atEnd() or (start < 2) ):
 				line = out.readLine() #QString
-				if ( find(line, "color[\"DefaultTextColor\"]") != -1 ):
+				if ( find("%s"%line, "color[\"DefaultTextColor\"]") != -1 ):
 					line = replace(line, "color[\"DefaultTextColor\"]", "")
 					line = replace(line, "=", "")
 					line = replace(line, "\"", "")
@@ -225,7 +225,7 @@ class WinNetStatExt( QtGui.QMainWindow ):
 					line = replace(line, " ", "")
 					self.color_text = line
 					start += 1 #++start
-				if ( find(line,"color[\"DefaultBackgroundColor\"]") != -1 ):
+				if ( find("%s"%line,"color[\"DefaultBackgroundColor\"]") != -1 ):
 					line = replace(line, "color[\"DefaultBackgroundColor\"]", "")
 					line = replace(line, "=", "") 
 					line = replace(line, "\"", "")
@@ -271,20 +271,20 @@ class WinNetStatExt( QtGui.QMainWindow ):
 
 	def tcpView(self, checked):
 		if checked:
-			self.ui.pb_tcp.setIcon( QtGui.QPixmap(":/pic128/pictures/tcp_on.png") )
+			self.ui.pb_tcp.setIcon( QtGui.QIcon(QtGui.QPixmap(":/pic128/pictures/tcp_on.png")) )
 			self.flPacket = "tcp"
 			self.getData()
 		else:
-			self.ui.pb_tcp.setIcon( QtGui.QPixmap(":/pic128/pictures/tcp_off.png") )
+			self.ui.pb_tcp.setIcon( QtGui.QIcon(QtGui.QPixmap(":/pic128/pictures/tcp_off.png")) )
 
 
 	def udpView(self, checked):
 		if checked:
-			self.ui.pb_udp.setIcon( QtGui.QPixmap(":/pic128/pictures/udp_on.png") )
+			self.ui.pb_udp.setIcon( QtGui.QIcon(QtGui.QPixmap(":/pic128/pictures/udp_on.png")) )
 			self.flPacket = "udp"
 			self.getData()
 		else:
-			self.ui.pb_udp.setIcon( QtGui.QPixmap(":/pic128/pictures/udp_off.png") )
+			self.ui.pb_udp.setIcon( QtGui.QIcon(QtGui.QPixmap(":/pic128/pictures/udp_off.png")) )
 
 
 	def getData(self):
@@ -408,9 +408,6 @@ class WinNetStatExt( QtGui.QMainWindow ):
 			icon.addPixmap(QtGui.QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_forward.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
 			self.ui.pb_infoProc.setIcon(icon)
 
-			#self.ui.pb_refresh.setEnabled( True )
-			#self.ui.pb_autorefresh.setEnabled( True )
-			#self.ui.pb_resolve.setEnabled( True )
 			self.ui.pb_tcp.setEnabled( True )
 			self.ui.pb_udp.setEnabled( True )
 		else:
@@ -422,9 +419,6 @@ class WinNetStatExt( QtGui.QMainWindow ):
 			icon.addPixmap(QtGui.QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_back.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
 			self.ui.pb_infoProc.setIcon(icon)
 
-			#self.ui.pb_refresh.setEnabled( False )
-			#self.ui.pb_autorefresh.setEnabled( False )
-			#self.ui.pb_resolve.setEnabled( False )
 			self.ui.pb_tcp.setEnabled( False )
 			self.ui.pb_udp.setEnabled( False )
 
