@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from PySide import QtCore, QtGui
+from PyQt4 import QtCore, QtGui
 import WindowFilterOptions
 import DateWindowExt
 from gettraff import GetTraff
 import myconfig
+from StatistData import pixmapIface_str
 
 class WindowFilterOptionsExt( QtGui.QMainWindow ):
 	def __init__(self, parent, parentUi, qset ):
@@ -63,18 +64,7 @@ class WindowFilterOptionsExt( QtGui.QMainWindow ):
 		item.setData( QtCore.Qt.UserRole+1, 0 )
 		listSupportIface = self.parent.db.optGetSupportIface()
 		for i in listSupportIface:
-			if i['iface'] == 'gprs0':
-				item_pic = ":/pic48/pictures/gprs.png"
-			elif i['iface'] == "wlan0":
-				item_pic = ":/pic48/pictures/wifi.png"
-			elif i['iface'] == "pan0":
-				item_pic = ":/pic48/pictures/pan.png"
-			elif ( i['iface'] == "eth0" ):
-				item_pic = ":/pic48/pictures/eth.png"
-			elif ( i['iface'] == "usb0" ):
-				item_pic = ":/pic48/pictures/usb.png"
-			else:
-				item_pic = ":/pic48/pictures/unknown.png"
+			item_pic = pixmapIface_str( i['iface'] )
 			item = QtGui.QListWidgetItem( QtGui.QIcon(QtGui.QPixmap(item_pic)), i['iface'] )
 			item.setData( QtCore.Qt.UserRole+1, i['type'] )
 			self.ui.lWIface.addItem( item )
@@ -110,6 +100,8 @@ class WindowFilterOptionsExt( QtGui.QMainWindow ):
 		n = self.ui.lWIface.currentRow()
 		item = self.ui.lWIface.item( n )
 		item_num = item.data( QtCore.Qt.UserRole+1 )
+		item_num = item_num.toInt()
+		item_num = item_num[0]
 
 		self.parentUI.pBFilter.setChecked( True )
 		self.hide()
