@@ -23,9 +23,17 @@ class MyDB:
 	def createDB(self):
 		sql_pragma = "PRAGMA foreign_keys = ON;"
 
+		#depricate
 		sql_create_alliface  = "CREATE TABLE IF NOT EXISTS 'main'.'alliface' ( "
 		sql_create_alliface += "'id' INTEGER UNIQUE PRIMARY KEY NOT NULL, "
 		sql_create_alliface += "'iface' TEXT NOT NULL);"
+		#--------
+
+		sql_drop_alliface = "DROP TABLE IF EXISTS 'main'.'alliface';"
+		
+		sql_create_alliface2  = "CREATE TABLE IF NOT EXISTS 'main'.'alliface2' ( "
+		sql_create_alliface2 += "'id' INTEGER UNIQUE PRIMARY KEY AUTOINCREMENT NOT NULL, "
+		sql_create_alliface2 += "'iface' TEXT NOT NULL);"
 
 		sql_create_type  = "CREATE TABLE IF NOT EXISTS 'main'.'type' ( "
 		sql_create_type += "'id' INTEGER UNIQUE PRIMARY KEY NOT NULL, "
@@ -58,12 +66,6 @@ class MyDB:
 		sql_create_commentsession += "'session_id' INTEGER REFERENCES 'session' ('id') ON DELETE CASCADE ON UPDATE CASCADE, "
 		sql_create_commentsession += "'comment' TEXT NOT NULL);"
 
-		sql_alliface_gprs = "INSERT INTO 'main'.'alliface' (id, iface) VALUES (1, 'gprs0')"
-		sql_alliface_wlan = "INSERT INTO 'main'.'alliface' (id, iface) VALUES (2, 'wlan0')"
-		sql_alliface_usb =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (3, 'usb0')"
-		sql_alliface_pan =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (4, 'pan0')"
-		sql_alliface_eth =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (5, 'eth0')"
-		
 		try:
 			R = self.cur.execute(sql_pragma)
 		except Exception, E:
@@ -97,32 +99,68 @@ class MyDB:
 
 		#--- alliface ---#
 		try:
-			R = self.cur.execute(sql_create_alliface)
+			R = self.cur.execute(sql_drop_alliface)
 		except Exception, E:
 			pass
 		try:
-			R = self.cur.execute(sql_alliface_gprs)
+			R = self.cur.execute(sql_create_alliface2)
 		except Exception, E:
 			pass
+
+		self.checkTableAllIface2()
+	#----------------#
+
+	def checkTableAllIface2(self):
+		sql_alliface_gprs = "INSERT INTO 'main'.'alliface2' (id, iface) VALUES (1, 'gprs0')"
+		sql_alliface_wlan = "INSERT INTO 'main'.'alliface2' (id, iface) VALUES (2, 'wlan0')"
+		sql_alliface_usb =  "INSERT INTO 'main'.'alliface2' (id, iface) VALUES (3, 'usb0')"
+		sql_alliface_pan =  "INSERT INTO 'main'.'alliface2' (id, iface) VALUES (4, 'pan0')"
+		sql_alliface_eth =  "INSERT INTO 'main'.'alliface2' (id, iface) VALUES (5, 'eth0')"
+		
+		SQL = "SELECT count(*) FROM 'main'.'alliface2'"
 		try:
-			R = self.cur.execute(sql_alliface_wlan)
+			self.cur.execute( SQL )
+			ret = self.cur.fetchone()[0]
+			if ret == None:
+				raise
+			ret = "%s"%ret
+			if ret == "0":
+				try:
+					R = self.cur.execute(sql_alliface_gprs)
+				except Exception, E:
+					print E
+					pass
+				try:
+					R = self.cur.execute(sql_alliface_wlan)
+				except Exception, E:
+					pass
+				try:
+					R = self.cur.execute(sql_alliface_usb)
+				except Exception, E:
+					pass
+				try:
+					R = self.cur.execute(sql_alliface_pan)
+				except Exception, E:
+					pass
+				try:
+					R = self.cur.execute(sql_alliface_eth)
+				except Exception, E:
+					pass
 		except Exception, E:
-			pass
+			print "MyDB::checkTableAllIface2(): [%s] %s\n"%(SQL,E)
+			ret = 0
+		return ret
+
+	def modifyTableSession(self):
+		SQL="ALTER TABLE 'main'.'session' ADD COLUMN 'iface' TEXT"
 		try:
-			R = self.cur.execute(sql_alliface_usb)
+			self.cur.execute( SQL )
 		except Exception, E:
+			print "MyDD::modifyTableSession(): Query error: %s"%E
 			pass
-		try:
-			R = self.cur.execute(sql_alliface_pan)
-		except Exception, E:
-			pass
-		try:
-			R = self.cur.execute(sql_alliface_eth)
-		except Exception, E:
-			pass
-		#----------------#
 		
 
+	#----------------#
 
 	def writeTraff(self, rx, tx, type, time_stamp = 0):
 		if ( rx != 0 ) and ( tx != 0 ):
@@ -176,7 +214,7 @@ class MyDB:
 	def getIfaceByType(self,type_id):
 		retVal = None
 		#sql = "SELECT iface FROM 'main'.'type' WHERE id == %s;"%(type_id)
-		sql = "SELECT iface FROM 'main'.'alliface' WHERE id == %s;"%(type_id)
+		sql = "SELECT iface FROM 'main'.'alliface2' WHERE id == %s;"%(type_id)
 		try:
 			self.cur.execute(sql)
 			retVal = self.cur.fetchone()[0]
@@ -189,7 +227,7 @@ class MyDB:
 	def getTypeByIface(self,iface):
 		retVal = None
 		#sql = "SELECT id FROM 'main'.'type' WHERE iface == '%s';"%(iface)
-		sql = "SELECT id FROM 'main'.'alliface' WHERE iface == '%s';"%(iface)
+		sql = "SELECT id FROM 'main'.'alliface2' WHERE iface == '%s';"%(iface)
 		try:
 			self.cur.execute(sql)
 			retVal = self.cur.fetchone()[0]
@@ -200,7 +238,7 @@ class MyDB:
 	
 	#возвращает полный 'список' сетевых интерфейсов
 	def getBuffIface(self):
-		SQL = "SELECT * FROM 'main'.'alliface'"
+		SQL = "SELECT * FROM 'main'.'alliface2'"
 		bufReturn = {}
 		try:
 			j = 0
@@ -211,6 +249,45 @@ class MyDB:
 		except Exception, E:
 			print "MyDB::getBuffIface(): [%s] %s\n"%(SQL, E)
 		return bufReturn
+	
+	#возвращает полный список сетевых интерфейсов
+	def getListIface(self):
+		SQL = "SELECT * FROM 'main'.'alliface2'"
+		listReturn = list()
+		try:
+			j = 0
+			for row in self.cur.execute( SQL ):
+				bufReturn = {}
+				type = row[0]
+				iface = row[1]
+				bufReturn[ "type" ] = type
+				bufReturn[ "iface" ] = iface
+				listReturn.append( bufReturn )
+		except Exception, E:
+			print "MyDB::getListIface(): [%s] %s\n"%(SQL, E)
+		return listReturn
+
+
+	def addGlobalIface(self, iface_name):
+		SQL = "INSERT INTO 'main'.'alliface2' (iface) VALUES ('%s')"%(iface_name)
+		ok = True
+		try:
+			self.cur.execute( SQL )
+		except Exception, E:
+			print "MyDB::addGlobalIface(): [%s] %s\n"%(SQL, E)
+			ok = False
+		return ok
+	
+	
+	def delGlobalIface(self, iface_name):
+		SQL = "DELETE FROM 'main'.'alliface2' WHERE `iface` == '%s'"%(iface_name)
+		ok = True
+		try:
+			self.cur.execute( SQL )
+		except Exception, E:
+			print "MyDB::delGlobalIface(): [%s] %s\n"%(SQL, E)
+			ok = False
+		return ok
 	#--------#
 
 
@@ -237,7 +314,7 @@ class MyDB:
 				listReturn.append(session)
 				j += 1
 		except Exception, E:
-			print "MyDB::getListSession(): %s\n"%E
+			print "MyDB::getListSession(): [%s] %s\n"%(SQL,E)
 
 		return listReturn
 	
@@ -621,7 +698,7 @@ class MyDB:
 			else:
 				self.cur.execute("UPDATE 'main'.'commentsession' SET comment=? WHERE session_id = ?;", ( comment_text, session_id ) )
 		except Exception, E:
-			print "MyDB::setCommentSession(): [%s] %s\n"%(SQL, E)
+			print "MyDB::setCommentSession(): %s\n"%E
 			ok = False
 		return ok
 
@@ -639,3 +716,21 @@ class MyDB:
 
 	#----------------------#
 
+	def checkTypeIfaceDB(self, iface_type):
+		SQL = "SELECT count(*) FROM 'main'.'session' WHERE type_id = %s"%iface_type
+
+		try:
+			self.cur.execute( SQL )
+			ret = self.cur.fetchone()[0]
+			if ret == None:
+				raise
+			ret = int( "%s"%ret, 10 )
+			if ret > 0:
+				return True
+			else:
+				return False
+		except Exception, E:
+			print "MyDB::checkTypeIfaceDB(): [%s] %s\n"%(SQL,E)
+			ret = False
+		return ret
+
