@@ -1,13 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from PySide import QtCore, QtGui
+from PyQt4 import QtCore, QtGui
 
 import dbus
 import dbus.service
 
 from sys import argv, exit
-#from os import geteuid, seteuid
 
 from pysrc import MainWindowExt
 from pysrc import myconfig
@@ -17,13 +16,6 @@ from dbus.mainloop.glib import DBusGMainLoop
 DBusGMainLoop(set_as_default=True)
 
 if __name__ == "__main__":
-#	try:
-#		myuid = geteuid()
-#		if myuid == 0:
-#			seteuid(29999)
-#	except:
-#		pass
-#	print "__main__: whoami: %s"%geteuid()
 	
 	app = QtGui.QApplication( argv )
 	
